pub struct Source { /* private fields */ }Expand description
A source code file, with line and column information
Implementations
Sourceimpl Source
impl Source
Sourcepub fn from_file(file: &Path) -> Source
pub fn from_file(file: &Path) -> Source
Create a new SourceCode from a file
The file should exist and be readable by the current user.
Also, the file should be encoded in UTF-8
Sourcepub fn from_string(source: String) -> Source
pub fn from_string(source: String) -> Source
Create a new SourceCode from a string
pub fn source(&self) -> &str
pub fn name(&self) -> &str
pub fn uri(&self) -> &str
Sourcepub fn line_at_offset(&self, offset: usize) -> usize
pub fn line_at_offset(&self, offset: usize) -> usize
Get the line number (0-based) at a given offset